—

# Groenvoorzieningwerk en werken in natuurterrein

The temperature of all fridges is checked daily

- Yes
- No
- Not applicable

The temperature in a fridge is critical to storing food. If the temperature is too high or fluctuates too much food can start rotting quickly.

#### Legal and policy references

The requirements for fridges are defined in section 13.1 section a of the health code.

Please leave any comments you may have on the question above in this field

1. Voorbereiden
2. Inventariseren
3. Evalueren
4. Plan van aanpak
5. Rapporten

Link to sector organisation | Disclaimer | About